function sxl_select,index,data,dtime,start=start,endt=endt,$
	minsamp=minsamp,tout=tout,nout=nout,ok=ok

;+
; NAME
;       sxl_select
; PURPOSE
;       To prepare data for sxl2irradiance.
;               1. Identify SXL data to be rejected because of offpointing
;                  hot CCD, eclipse, etc., etc. (about 2%).
;               2. Average data into dtime intervals, uses divyup.pro.
; INPUT
;       index, index structure from output of sxl_analys.pro
;	data,  DN/s signal array from sxl_analysis
;	dtime, time interval (seconds) over which to average data
; KEYWORD INPUT
;	start, the starting time for grouping of data by divyup.pro
;	endt, the ending time for grouping of data.  If groups extend
;		beyond this time the later groups are deleted.
; OPTIONAL KEYWORD INPUT
;       minsamp, minimum samples in an interval required for processing,
;               default = 1
; OUTPUT
;	Array of average signal levels for each time interval.
;	Intervals with no valid data set equal to -1.
; KEYWORD OUTPUT
;       tout, structure of mid-points of day averages.
; OPTIONAL KEYWORD OUTPUT
;       nout, array giving number of samples in each average value.
;       ok, indices of good data
; PROGRAMS CALLED
;	int2secarr, sxl_clip, divyup
; HISTORY
;       24-Jun-99, LWA, rewritten from sxl_dg_analysis.pro
;	28-Jun-99, LWA, added start keyword
;	 4-Nov-99, LWA, replaced delind with kill_index
;			fixed problem with reject_dates section
;-


; NOTE, All the dg's used below are holdovers from sxl_dg_analysis.
;    However, don't worry, the program is no longer filter-specific.
;    LWA, 6/24/99

dg=reform(temporary(data(0,*)))  ;Extract full-image flux array.

; Acceptable region for pointing:  x=437:587, y=437:630 FRpix
; Derived mainly from pointing statistics and common sense.
; Thus, somewhat arbitrary and subject to modification.
; However, the go/no-go pointing selection must be set in 
; sxl_analysis.pro where the decision is made and the flag is set.

onctr_dg=where(index.onctr eq 1) 
offctr_dg=where(index.onctr eq 0) 

xdg=lindgen(n_elements(dg))
cool_dg=where(gt_temp_ccd(index) le -20)
hot_dg=where(gt_temp_ccd(index) gt -20)
pos_dg=where(dg gt 0)
neg_dg=where(dg le 0)

; Hardwired reject dates with problem data.
tt=int2secarr(index,'1-jan-91')
dd1=int2secarr('24-Oct-95 00:00','1-jan-91')
dd2=int2secarr('30-Oct-95 00:00','1-jan-91')
ec1=int2secarr('26-feb-98 14:50','1-jan-91')
ec2=int2secarr('26-feb-98 19:20','1-jan-91')
if ((dd1 ge min(tt) and dd1 le max(tt)) or $
    (dd2 ge min(tt) and dd2 le max(tt)) or $
    (ec1 ge min(tt) and ec2 le max(tt)) or $
    (ec2 ge min(tt) and ec2 le max(tt))) then begin 
   date1=tim2dset(index,'24-Oct-95 00:00')
   date2=tim2dset(index,'30-Oct-95 00:00')
   eclipse1=tim2dset(index,'26-feb-98 14:50')
   eclipse2=tim2dset(index,'26-feb-98 19:20')
   case 1 of
      date1 eq date2 : reject_dates=[lindgen(eclipse2-eclipse1)+eclipse1]
      eclipse1 eq eclipse2: reject_dates=[lindgen(date2-date1)+date1]
      else : reject_dates=[lindgen(date2-date1)+date1,lindgen(eclipse2-eclipse1)+eclipse1]
   endcase
   bad=[offctr_dg,hot_dg,reject_dates,neg_dg]
   bad=bad(uniq(bad,sort(bad)))
endif else begin
   bad=[offctr_dg,hot_dg,neg_dg]
   bad=bad(uniq(bad,sort(bad)))
endelse

gud_dg=kill_index(xdg,bad)

sxl_clip,dg(gud_dg),keep_dg,/keep,level=.5,/noplot
sxl_clip,dg(gud_dg),nkeep_dg,level=.5,/noplot
ok=gud_dg(keep_dg)

if NOT keyword_set(minsamp) then minsamp=1 else minsamp=minsamp

divyup,index(ok),dg(ok),dtime,start=start,minsamp=minsamp,dout,tout,nout
nt=tim2dset(tout,endt)
;help,dout,tout,nout,nt
;print,nt

if nt+1 lt n_elements(tout) then begin
   tout=tout(lindgen(nt))
   dout=dout(lindgen(nt))
   nout=nout(lindgen(nt))
endif
;help,dout,tout,nout,nt

return,dout

end
